@@ -1,12 +1,11 @@
-#line 1 "inc/Module/Install/PRIVATE/PAR.pm - /usr/local/lib/perl5/site_perl/5.8.4/Module/Install/PRIVATE/PAR.pm"
+#line 1 "inc/Module/Install/PRIVATE/PAR.pm - /usr/local/lib/perl5/site_perl/5.8.0/Module/Install/PRIVATE/PAR.pm"
 # $File: //member/autrijus/Module-Install-PRIVATE/lib/Module/Install/PRIVATE/PAR.pm $ $Author: autrijus $
-# $Revision: #14 $ $Change: 10724 $ $DateTime: 2004/06/02 09:57:09 $ vim: expandtab shiftwidth=4
+# $Revision: #2 $ $Change: 5848 $ $DateTime: 2003/05/14 20:24:03 $ vim: expandtab shiftwidth=4
 
 package Module::Install::PRIVATE::PAR;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
 use 5.006;
-use FindBin;
 use Config ();
 
 my %no_parl  = ();
@@ -17,7 +16,6 @@ sub Autrijus_PAR {
     my $cc   = $self->can_cc unless $bork;
     my $par  = $self->fetch_par('', '', !$cc) unless $cc or $bork;
     my $exe  = $Config::Config{_exe};
-    my $dynperl = $Config::Config{useshrplib} && ($Config::Config{useshrplib} ne 'false');
 
     if ($bork) {
         warn "Binary loading known to fail on $^O; won't generate 'script/parl$exe'!\n";
@@ -38,17 +36,13 @@ sub Autrijus_PAR {
     } 
 
     my @bin = ("script/parl$exe", "myldr/par$exe");
-    push @bin, ("script/parldyn$exe", "myldr/static$exe") if $dynperl;
-
-    $FindBin::Bin = '.' unless -e "$FindBin::Bin/Makefile.PL";
-    my $par_exe = "$FindBin::Bin/$bin[1]";
 
     if ($par) {
-        open my $fh, '>', $par_exe or die "Cannot write to $par_exe";
-        close $fh;
+        open _, "> $bin[1]" or die $!;
+        close _;
     }
-    elsif (-f $par_exe and not -s $par_exe) {
-        unlink $par_exe;
+    elsif (-f $bin[1] and not -s $bin[1]) {
+        unlink $bin[1];
     }
 
     $self->clean_files(@bin) if $par or $cc;
@@ -57,7 +51,6 @@ sub Autrijus_PAR {
         MAN1PODS		=> {
             'script/par.pl'	=> 'blib/man1/par.pl.1',
             'script/pp'	        => 'blib/man1/pp.1',
-            'script/tkpp'       => 'blib/man1/tkpp.1',
           ($par or $cc) ? (
             'script/parl.pod'   => 'blib/man1/parl.1',
           ) : (),
@@ -65,12 +58,8 @@ sub Autrijus_PAR {
         EXE_FILES		=> [
             'script/par.pl',
             'script/pp',
-            'script/tkpp',
           (!$par and $cc) ? (
             "script/parl$exe",
-            $dynperl ? (
-                "script/parldyn$exe",
-            ) : (),
           ) : (),
         ],
         DIR                     => [
@@ -84,21 +73,19 @@ sub Autrijus_PAR {
 
 sub Autrijus_PAR_fix {
     my $self = shift;
-
+    require Config;
     my $exe = $Config::Config{_exe};
     return unless $exe eq '.exe';
 
-    open my $in, '<', "$FindBin::Bin/Makefile" or return;
-    open my $out, '>', "$FindBin::Bin/Makefile.new" or return;
-    while (<$in>) {
-        next if /^\t\$\(FIXIN\) .*\Q$exe\E$/;
-        next if /^\@\[$/ or /^\]$/;
-        print $out $_;
+    open IN, '< Makefile' or return;
+    open OUT, '> Makefile.new' or return;
+    while (<IN>) {
+        print OUT $_ unless /^\t\$\(FIXIN\) .*\Q$exe\E$/;
     }
-    close $out;
-    close $in;
-    unlink "$FindBin::Bin/Makefile";
-    rename "$FindBin::Bin/Makefile.new" => "$FindBin::Bin/Makefile";
+    close OUT;
+    close IN;
+    unlink 'Makefile';
+    rename 'Makefile.new' => 'Makefile';
 }
 
 1;
