@@ -1,8 +1,8 @@
 # $File: //member/autrijus/PAR/lib/PAR.pm $ $Author: autrijus $
-# $Revision: #5 $ $Change: 5071 $ $DateTime: 2003/03/31 18:52:32 $ vim: expandtab shiftwidth=4
+# $Revision: #12 $ $Change: 6085 $ $DateTime: 2003/05/25 18:32:18 $ vim: expandtab shiftwidth=4
 
 package PAR;
-$PAR::VERSION = '0.67';
+$PAR::VERSION = '0.68';
 
 use 5.006;
 use strict;
@@ -15,7 +15,7 @@ PAR - Perl Archive Toolkit
 
 =head1 VERSION
 
-This document describes version 0.67 of PAR, released April 1, 2003.
+This document describes version 0.68 of PAR, released May 26, 2003.
 
 =head1 SYNOPSIS
 
@@ -107,11 +107,6 @@ Please see L</SYNOPSIS> for most typical use cases.
 
 =head1 NOTES
 
-Since version 0.60, all files and data are extracted into a temporary
-directory, with the same name as its CRC32 checksum, to speed up the
-loading time of the next round.  To inhibit this behavior, set the
-C<PAR_CLEARTEMP> environment to a true value.
-
 In the next few releases, it is expected that the F<META.yml> packed
 inside the PAR file will control the default behavior of temporary file
 creation, among other things; F<pp> will also provide options to set those
@@ -154,7 +149,7 @@ sub import {
         push @PAR_INC, $par if unpar($par, undef, undef, 1);
     }
 
-    push @INC, \&find_par unless grep { $_ eq \&find_par } @INC;
+    unshift @INC, \&find_par unless grep { $_ eq \&find_par } @INC;
 
     require PAR::Heavy;
     PAR::Heavy::_init_dynaloader();
@@ -234,6 +229,7 @@ sub unpar {
     my ($par, $file, $member_only, $allow_other_ext) = @_;
     my $zip = $LibCache{$par};
 
+    return if $PAR::__reading;
     local $PAR::__reading = 1;
 
     unless ($zip) {
